#####
Utils
#####

This simply contains a number of useful utilities that are shared between the various ROMSearch modules. In particular,
we use centralised code for reading of files, logging, string matching using regex, and Discord posting.

API
===

.. automodule:: romsearch.util
    :no-index:
    :members:
    :undoc-members:
